pub enum WrapMode {
Hard,
Soft(f32),
}Expand description
Wrap mode for the text area.
Variants
Hard
Hard wrap: newlines only, no soft wrap.
Soft(f32)
Soft wrap: wrap at max_width pixels.
When rendering, long lines are split using an estimated char width of
max_width / 8.0 pixels (since this layer has no access to a live
shaper).