pub struct HyperlinkSpan {
pub start: usize,
pub end: usize,
pub url: String,
}Expand description
A URL-like substring found within a text string.
Fields
start: usizeByte offset of the first character of the URL (inclusive).
end: usizeByte offset just past the last character of the URL (exclusive).
url: StringThe matched URL text.